==> onos-yang-runtime-2.2.0-b1-sources.jar: org/onosproject/yang/gen/v1/augmentchoice/rev20160826/augmentchoice/contenttest/valid/augmentedschvalid/AugCaseModKeyKeys.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.augmentchoice.rev20160826.augmentchoice.contenttest.valid.augmentedschvalid;

import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of augCaseModKey.
 */
public class AugCaseModKeyKeys implements KeyInfo<DefaultAugCaseModKey> {
    protected int types;
    /**
     * Returns the attribute types.
     *
     * @return types value of types
     */
    public int types() {
        return types;
    }

    /**
     * Sets the value to attribute types.
     *
     * @param types value of types
     */
    public void types(int types) {
        this.types = types;
    }


    @Override
    public int hashCode() {
        return Objects.hash(types);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof AugCaseModKeyKeys) {
            AugCaseModKeyKeys other = (AugCaseModKeyKeys) obj;
            return
                Objects.equals(types, other.types);
        }
        return false;
    }
}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/augmentchoice/rev20160826/augmentchoice/contenttest/valid/augmentedschvalid/AugCaseModKeyKeys.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.augmentchoice.rev20160826.augmentchoice.contenttest.valid.augmentedschvalid;

import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of augCaseModKey.
 */
public class AugCaseModKeyKeys implements KeyInfo<DefaultAugCaseModKey> {
    protected int types;
    /**
     * Returns the attribute types.
     *
     * @return types value of types
     */
    public int types() {
        return types;
    }

    /**
     * Sets the value to attribute types.
     *
     * @param types value of types
     */
    public void types(int types) {
        this.types = types;
    }


    @Override
    public int hashCode() {
        return Objects.hash(types);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof AugCaseModKeyKeys) {
            AugCaseModKeyKeys other = (AugCaseModKeyKeys) obj;
            return
                Objects.deepEquals(types, other.types);
        }
        return false;
    }
}
